@@ -1,7 +1,7 @@
 package PICA::Writer::Plain;
 use v5.14.1;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 use charnames qw(:full);
 use Term::ANSIColor;
@@ -29,6 +29,18 @@ sub write_subfield {
     $self->{fh}->print($value);
 }
 
+sub write_annotation {
+    my ($self, $field) = @_;
+
+    if (@$field % 2) {
+        $self->{fh}->print($field->[$#$field] . " ")
+            unless defined $self->{annotated} && !$self->{annotated};
+    }
+    elsif ($self->{annotated}) {
+        $self->{fh}->print("  ");
+    }
+}
+
 1;
 __END__
 
@@ -42,4 +54,7 @@ See L<PICA::Writer::Base> for synopsis and details.
 
 The counterpart of this module is L<PICA::Parser::Plain>.
 
+This writer also supports annotated PICA by default. Use option C<annotated> to
+ensure or ignore field annotations.
+
 =cut
